@@ -1,6 +1,6 @@
 # ABSTRACT: encapsulation of Dancer2 packages
 package Dancer2::Core::App;
-$Dancer2::Core::App::VERSION = '0.200001';
+$Dancer2::Core::App::VERSION = '0.200002';
 use Moo;
 use Carp               qw<croak carp>;
 use Scalar::Util       'blessed';
@@ -1224,7 +1224,11 @@ sub make_forward_to {
     # and merge existing params
     delete $env->{CONTENT_LENGTH};
 
-    my $new_request = Dancer2::Core::Request->new( env => $env, body_params => {} );
+    my $new_request = Dancer2::Core::Request->new(
+        env         => $env,
+        body_params => {},
+    );
+
     my $new_params = _merge_params( scalar( $request->params ), $params || {} );
 
     exists $options->{method} and
@@ -1237,8 +1241,10 @@ sub make_forward_to {
     $new_request->{_route_params} = $request->{_route_params};
     $new_request->{body}          = $request->body;
     $new_request->{headers}       = $request->headers;
+
     # Copy remaining settings
     $new_request->{is_behind_proxy} = $request->{is_behind_proxy};
+    $new_request->{vars}            = $request->{vars};
 
     # If a session object was created during processing of the original request
     # i.e. a session object exists but no cookie existed
@@ -1563,7 +1569,7 @@ Dancer2::Core::App - encapsulation of Dancer2 packages
 
 =head1 VERSION
 
-version 0.200001
+version 0.200002
 
 =head1 DESCRIPTION
 
